pygeodesy.triaxials.triaxial5.ConformalSphere

Package pygeodesy :: Package triaxials :: Module triaxial5 :: Class ConformalSphere |
[frames] | no frames]

# Class ConformalSphere

          object --+
                   |
        named._Named --+
                       |
        named._NamedBase --+
                           |
        named._NamedEnumItem --+
                               |
    bases._UnOrderedTriaxialBase --+
                                   |
          bases._OrderedTriaxialBase --+
                                       |
                                Triaxial --+
                                           |
                                   Conformal --+
                                               |
                                              ConformalSphere

Known Subclasses:
  - deprecated.classes.JacobiConformalSpherical

Alternate, Jacobi Conformal projection on a spherical triaxial.

See Also: Conformal for more information.

Instance Methods
__init__(self, radius_conformal, ab=0, bc=0, **name) New ConformalSphere. |
Inherited from `Conformal`: `x`, `xR`, `xR_`, `xy`, `xyR2`, `xyR2_`, `y`, `yR`, `yR_` Inherited from `Triaxial`: `forwardBetaOmega`, `forwardBetaOmega_`, `forwardCartesian`, `forwardLatLon`, `forwardLatLon_`, `reverseBetaOmega`, `reverseCartesian`, `reverseLatLon` Inherited from `bases._UnOrderedTriaxialBase`: `__repr__`, `areaKT`, `area_p`, `ellipse5`, `hartzell4`, `height4`, `normal3d`, `normal4`, `sideOf`, `toBiaxial`, `toEllipsoid`, `toStr` Inherited from `named._NamedEnumItem`: `unregister` Inherited from `named._NamedBase`: `__str__`, `others`, `toRepr` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| ab Get relative magnitude `a - b` (`meter`, same units as `a`).
| bc Get relative magnitude `b - c` (`meter`, same units as `a`).
| radius Get radius (`meter`, conventionally).
Inherited from `Conformal`: `xyQ2`, `xyQR2` Inherited from `bases._OrderedTriaxialBase`: `area`, `area21k` Inherited from `bases._UnOrderedTriaxialBase`: `R2`, `R3`, `Rauthalic`, `Rvolumetric`, `a`, `a2`, `abc3`, `areaRG`, `b`, `b2`, `c`, `c2`, `e2ab`, `e2ac`, `e2bc`, `isFlat`, `isOblate`, `isOrdered`, `isProlate`, `isSpherical`, `perimeter4ab`, `perimeter4ac`, `perimeter4bc`, `unOrdered`, `volume` Inherited from `named._NamedEnumItem`: `name` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, radius_conformal, ab=0, bc=0, **name) (Constructor) |
New ConformalSphere. Arguments: `radius_conformal` - Radius (`scalar`, conventionally in `meter`) or an other ConformalSphere or Conformal. `ab` - Relative magnitude of `a - b` (`meter`, same units as `scalar radius`. `bc` - Relative magnitude of `b - c` (`meter`, same units as `scalar radius`. `name` - Optional `name=NN` (`str`). Raises: `TriaxialError` - Invalid `radius_conformal`, negative `ab`, negative `bc` or `(ab + bc)` not positive. Overrides: object.__init__ Note: If `radius_conformal` is a ConformalSphere and if `ab` and `bc` are both zero or `None`, the `radius_conformal`'s `ab`, `bc`, `a`, `b` and `c` are copied.

Property Details

### ab Get relative magnitude `a - b` (`meter`, same units as `a`). Get method: ab(self) - Get relative magnitude `a - b` (`meter`, same units as `a`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### bc Get relative magnitude `b - c` (`meter`, same units as `a`). Get method: bc(self) - Get relative magnitude `b - c` (`meter`, same units as `a`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### radius Get radius (`meter`, conventionally). Get method: radius(self) - Get radius (`meter`, conventionally). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.